summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorBruce Mitchener <bruce.mitchener@gmail.com>2024-12-03 02:47:52 +0700
committerGitHub <noreply@github.com>2024-12-02 11:47:52 -0800
commitc8f8f73a8e5506a45ddc86dafaad99a024d83361 (patch)
tree888ee495ab273325679bba3e7bff8f0e1c5cccf0 /include
parenteaa8dcfcc9deabb906cc09bf31fc17ab6f343ff4 (diff)
includes: Reduce typo count (#5710)
Co-authored-by: Yong He <yonghe@outlook.com>
Diffstat (limited to 'include')
-rw-r--r--include/slang-deprecated.h8
-rw-r--r--include/slang.h42
2 files changed, 25 insertions, 25 deletions
diff --git a/include/slang-deprecated.h b/include/slang-deprecated.h
index 3ce8f61bc..82d81af75 100644
--- a/include/slang-deprecated.h
+++ b/include/slang-deprecated.h
@@ -101,7 +101,7 @@ extern "C"
int targetIndex,
bool val);
- /*! @see slang::ICompileRequest::setIngoreCapabilityCheck */
+ /*! @see slang::ICompileRequest::setIgnoreCapabilityCheck */
SLANG_API void spSetIgnoreCapabilityCheck(slang::ICompileRequest* request, bool val);
/*! @see slang::ICompileRequest::setCodeGenTarget */
@@ -936,11 +936,11 @@ extern "C"
/// Count should *NOT* include terminating zero.
SLANG_API SlangUInt32 spComputeStringHash(const char* chars, size_t count);
- /// Get a type layout representing reflection information for the global-scope prameters.
+ /// Get a type layout representing reflection information for the global-scope parameters.
SLANG_API SlangReflectionTypeLayout* spReflection_getGlobalParamsTypeLayout(
SlangReflection* reflection);
- /// Get a variable layout representing reflection information for the global-scope prameters.
+ /// Get a variable layout representing reflection information for the global-scope parameters.
SLANG_API SlangReflectionVariableLayout* spReflection_getGlobalParamsVarLayout(
SlangReflection* reflection);
@@ -1409,7 +1409,7 @@ struct ICompileRequest : public ISlangUnknown
virtual SLANG_NO_THROW void const* SLANG_MCALL getCompileRequestCode(size_t* outSize) = 0;
/** Get the compilation result as a file system.
- The result is not written to the actual OS file system, but is made avaiable as an
+ The result is not written to the actual OS file system, but is made available as an
in memory representation.
*/
virtual SLANG_NO_THROW ISlangMutableFileSystem* SLANG_MCALL
diff --git a/include/slang.h b/include/slang.h
index 5e64ce0b9..80a132914 100644
--- a/include/slang.h
+++ b/include/slang.h
@@ -305,7 +305,7 @@ convention for interface methods.
/// SLANG_INLINE exists to have a way to inline consistent with SLANG_ALWAYS_INLINE
#define SLANG_INLINE inline
// If explicilty disabled and not set, set to not available
#if !defined(SLANG_HAS_EXCEPTIONS) && defined(SLANG_DISABLE_EXCEPTIONS)
#define SLANG_HAS_EXCEPTIONS 0
#endif
@@ -488,9 +488,9 @@ convention for interface methods.
#define SLANG_UNALIGNED_ACCESS 0
#endif
-// One endianess must be set
+// One endianness must be set
#if ((SLANG_BIG_ENDIAN | SLANG_LITTLE_ENDIAN) == 0)
- #error "Couldn't determine endianess"
+ #error "Couldn't determine endianness"
#endif
#ifndef SLANG_NO_INTTYPES
@@ -551,7 +551,7 @@ typedef uint32_t SlangSizeT;
{
SLANG_SEVERITY_DISABLED = 0, /**< A message that is disabled, filtered out. */
SLANG_SEVERITY_NOTE, /**< An informative message. */
- SLANG_SEVERITY_WARNING, /**< A warning, which indicates a possible proble. */
+ SLANG_SEVERITY_WARNING, /**< A warning, which indicates a possible problem. */
SLANG_SEVERITY_ERROR, /**< An error, indicating that compilation failed. */
SLANG_SEVERITY_FATAL, /**< An unrecoverable error, which forced compilation to abort. */
SLANG_SEVERITY_INTERNAL, /**< An internal error, indicating a logic error in the compiler.
@@ -811,10 +811,10 @@ typedef uint32_t SlangSizeT;
{
SLANG_DEBUG_INFO_LEVEL_NONE = 0, /**< Don't emit debug information at all. */
SLANG_DEBUG_INFO_LEVEL_MINIMAL, /**< Emit as little debug information as possible, while
- still supporting stack trackes. */
+ still supporting stack trackers. */
SLANG_DEBUG_INFO_LEVEL_STANDARD, /**< Emit whatever is the standard level of debug
information for each target. */
- SLANG_DEBUG_INFO_LEVEL_MAXIMAL, /**< Emit as much debug infromation as possible for each
+ SLANG_DEBUG_INFO_LEVEL_MAXIMAL, /**< Emit as much debug information as possible for each
target. */
};
@@ -823,7 +823,7 @@ typedef uint32_t SlangSizeT;
enum SlangDebugInfoFormat : SlangDebugInfoFormatIntegral
{
SLANG_DEBUG_INFO_FORMAT_DEFAULT, ///< Use the default debugging format for the target
- SLANG_DEBUG_INFO_FORMAT_C7, ///< CodeView C7 format (typically means debugging infomation is
+ SLANG_DEBUG_INFO_FORMAT_C7, ///< CodeView C7 format (typically means debugging information is
///< embedded in the binary)
SLANG_DEBUG_INFO_FORMAT_PDB, ///< Program database
@@ -1958,14 +1958,14 @@ public: \
// This `MyParams` type introduces two existential type parameters:
// one for `material` and one for `lights`. Even though `lights`
// is an array, it only introduces one type parameter, because
- // we need to hae a *single* concrete type for all the array
+ // we need to have a *single* concrete type for all the array
// elements to be able to generate specialized code.
//
SLANG_PARAMETER_CATEGORY_EXISTENTIAL_TYPE_PARAM,
// An existential object parameter represents a value
// that needs to be passed in to provide data for some
- // interface-type shader paameter.
+ // interface-type shader parameter.
//
// Consider this example:
//
@@ -2025,13 +2025,13 @@ public: \
parameters of different types as occupying the same binding space for layout
(e.g., in SPIR-V both a `Texture2D` and `SamplerState` use the same space of
`binding` indices, and are not allowed to overlap), while those same types
- map to different types of bindingsin the API (e.g., both textures and samplers
+ map to different types of bindings in the API (e.g., both textures and samplers
use different `VkDescriptorType` values).
When you want to answer "what register/binding did this parameter use?" you
should use `SlangParameterCategory`.
- When you wnat to answer "what type of descriptor range should this parameter use?"
+ When you want to answer "what type of descriptor range should this parameter use?"
you should use `SlangBindingType`.
*/
typedef SlangUInt32 SlangBindingTypeIntegral;
@@ -3601,7 +3601,7 @@ struct IGlobalSession : public ISlangUnknown
*/
virtual SLANG_NO_THROW ISlangSharedLibraryLoader* SLANG_MCALL getSharedLibraryLoader() = 0;
- /** Returns SLANG_OK if a the compilation target is supported for this session
+ /** Returns SLANG_OK if the compilation target is supported for this session
@param target The compilation target to test
@return SLANG_OK if the target is available
@@ -3611,7 +3611,7 @@ struct IGlobalSession : public ISlangUnknown
virtual SLANG_NO_THROW SlangResult SLANG_MCALL
checkCompileTargetSupport(SlangCompileTarget target) = 0;
- /** Returns SLANG_OK if a the pass through support is supported for this session
+ /** Returns SLANG_OK if the pass through support is supported for this session
@param session Session
@param target The compilation target to test
@return SLANG_OK if the target is available
@@ -3689,7 +3689,7 @@ struct IGlobalSession : public ISlangUnknown
* @param argc The number of command line arguments.
* @param argv An input array of command line arguments to parse.
* @param outSessionDesc A pointer to a SessionDesc struct to receive parsed session desc.
- * @param outAuxAllocation Auxillary memory allocated to hold data used in the sesion desc.
+ * @param outAuxAllocation Auxiliary memory allocated to hold data used in the session desc.
*/
virtual SLANG_NO_THROW SlangResult SLANG_MCALL parseCommandLineArguments(
int argc,
@@ -3815,7 +3815,7 @@ information.
In order to be able to load code, the session owns a set
of active "search paths" for resolving `#include` directives
-and `import` declrations, as well as a set of global
+and `import` declarations, as well as a set of global
preprocessor definitions that will be used for all code
that gets `import`ed in the session.
@@ -3880,7 +3880,7 @@ struct ISession : public ISlangUnknown
function will return null.
It is an error to create a composite component type that recursively
- aggregates the a single module more than once.
+ aggregates a single module more than once.
*/
virtual SLANG_NO_THROW SlangResult SLANG_MCALL createCompositeComponentType(
IComponentType* const* componentTypes,
@@ -3953,7 +3953,7 @@ struct ISession : public ISlangUnknown
to explicitly specify which implementation types should be included in the final compiled
code. For example, if an module defines `IMaterial` interface and `AMaterial`,
`BMaterial`, `CMaterial` types that implements the interface, the user can exclude
- `CMaterial` implementation from the resulting shader code by explcitly adding
+ `CMaterial` implementation from the resulting shader code by explicitly adding
`AMaterial:IMaterial` and `BMaterial:IMaterial` conformances to a composite
`IComponentType` and get entry point code from it. The resulting code will not have
anything related to `CMaterial` in the dynamic dispatch logic. If the user does not
@@ -4006,7 +4006,7 @@ struct IMetadata : public ISlangCastable
SLANG_COM_INTERFACE(0x8044a8a3, 0xddc0, 0x4b7f, {0xaf, 0x8e, 0x2, 0x6e, 0x90, 0x5d, 0x73, 0x32})
/*
- Returns whether a resource parameter at the specifieid binding location is actually being used
+ Returns whether a resource parameter at the specified binding location is actually being used
in the compiled shader.
*/
virtual SlangResult isParameterLocationUsed(
@@ -4136,7 +4136,7 @@ struct IComponentType : public ISlangUnknown
Has the same requirements as getEntryPointCode.
- The result is not written to the actual OS file system, but is made avaiable as an
+ The result is not written to the actual OS file system, but is made available as an
in memory representation.
*/
virtual SLANG_NO_THROW SlangResult SLANG_MCALL getResultAsFileSystem(
@@ -4166,7 +4166,7 @@ struct IComponentType : public ISlangUnknown
IComponentType** outSpecializedComponentType,
ISlangBlob** outDiagnostics = nullptr) = 0;
- /** Link this component type against all of its unsatisifed dependencies.
+ /** Link this component type against all of its unsatisfied dependencies.
A component type may have unsatisfied dependencies. For example, a module
depends on any other modules it `import`s, and an entry point depends
@@ -4179,7 +4179,7 @@ struct IComponentType : public ISlangUnknown
It is an error to try to generate/access compiled kernel code for
a component type with unresolved dependencies, so if dependencies
remain after whatever manual composition steps an application
- cares to peform, the `link()` function can be used to automatically
+ cares to perform, the `link()` function can be used to automatically
compose in any remaining dependencies. The order of parameters
(and hence the global layout) that results will be deterministic,
but is not currently documented.
@@ -305,7 +305,7 @@ convention for interface methods.
/// SLANG_INLINE exists to have a way to inline consistent with SLANG_ALWAYS_INLINE
#define SLANG_INLINE inline
-// If explicilty disabled and not set, set to not available
+// If explicitly disabled and not set, set to not available
#if !defined(SLANG_HAS_EXCEPTIONS) && defined(SLANG_DISABLE_EXCEPTIONS)
#define SLANG_HAS_EXCEPTIONS 0